# -*- coding: utf-8 -*-
"""
    author: jiege
    url: http://jieguone.top
    copyright: © jieguone.top
    license: none
    date : 2019/4/4 0:31
    ide : PyCharm
"""

class logtool:

    def info(self, strLog):
        """
            author: jiege
            url: http://jieguone.top
            copyright: © jieguone.top
            license: none
            date : 2019/4/4 0:31
            ide : PyCharm
        """
        print(strLog)